@@ -16,6 +16,9 @@ class BPickleTest(unittest.TestCase):
         self.assertTrue("e" in repr(number))
         self.assertAlmostEquals(bpickle.loads(bpickle.dumps(number)), number)
 
+    def test_bytes(self):
+        self.assertEqual(bpickle.loads(bpickle.dumps(b'foo')), b'foo')
+
     def test_string(self):
         self.assertEqual(bpickle.loads(bpickle.dumps('foo')), 'foo')
 
@@ -45,6 +48,16 @@ class BPickleTest(unittest.TestCase):
         self.assertEqual(bpickle.loads(dumped_tobool),
                          {True: False})
 
+    def test_dict_bytes_keys(self):
+        """Check loading dict bytes keys without reinterpreting."""
+        # Happens in amp and broker. Since those messages are meant to be
+        # forwarded to the server without changing schema, keys shouldn't be
+        # decoded in this case.
+        initial_data = {b"hello": True}
+        data = bpickle.dumps(initial_data)
+        result = bpickle.loads(data, as_is=True)
+        self.assertEqual(initial_data, result)
+
     def test_long(self):
         long = 99999999999999999999999999999
         self.assertEqual(bpickle.loads(bpickle.dumps(long)), long)
