@@ -1,12 +1,19 @@
 import os
+import unittest
 
+from mock import patch
+
+from landscape.lib import testing
 from landscape.lib.disk import (
     get_filesystem_for_path, get_mount_info, is_device_removable,
     _get_device_removable_file_path)
-from landscape.tests.helpers import LandscapeTest
 
 
-class DiskUtilitiesTest(LandscapeTest):
+class BaseTestCase(testing.FSTestCase, unittest.TestCase):
+    pass
+
+
+class DiskUtilitiesTest(BaseTestCase):
 
     def setUp(self):
         super(DiskUtilitiesTest, self).setUp()
@@ -40,7 +47,8 @@ class DiskUtilitiesTest(LandscapeTest):
         f.write(content)
         f.close()
         for point in points:
-            self.stat_results[point] = (4096, 0, 1000, 500, 0, 0, 0, 0, 0)
+            self.stat_results[point] = os.statvfs_result(
+                (4096, 0, 1000, 500, 0, 0, 0, 0, 0, 0))
 
     def test_get_filesystem_for_path(self):
         self.set_mount_points(["/"])
@@ -49,7 +57,8 @@ class DiskUtilitiesTest(LandscapeTest):
 
     def test_get_filesystem_subpath(self):
         self.set_mount_points(["/"])
-        self.stat_results["/"] = (4096, 0, 1000, 500, 0, 0, 0, 0, 0)
+        self.stat_results["/"] = os.statvfs_result(
+            (4096, 0, 1000, 500, 0, 0, 0, 0, 0, 0))
         info = get_filesystem_for_path("/home", self.mount_file, self.statvfs)
         self.assertEqual(info["mount-point"], "/")
 
@@ -80,7 +89,7 @@ class DiskUtilitiesTest(LandscapeTest):
         self.set_mount_points(["/secret"], read_access=False)
         info = get_filesystem_for_path(
             "/secret", self.mount_file, self.statvfs)
-        self.assertIdentical(info, None)
+        self.assertIs(info, None)
 
     def test_ignore_unmounted_and_virtual_mountpoints(self):
         """
@@ -97,7 +106,8 @@ class DiskUtilitiesTest(LandscapeTest):
         f.write(content)
         f.close()
 
-        self.stat_results["/home"] = (4096, 0, 1000, 500, 0, 0, 0, 0, 0)
+        self.stat_results["/home"] = os.statvfs_result(
+            (4096, 0, 1000, 500, 0, 0, 0, 0, 0, 0))
 
         result = [x for x in get_mount_info(self.mount_file, self.statvfs)]
         expected = {"device": "/dev/sda1", "mount-point": "/home",
@@ -105,9 +115,10 @@ class DiskUtilitiesTest(LandscapeTest):
         self.assertEqual([expected], result)
 
 
-class RemovableDiskTest(LandscapeTest):
+class RemovableDiskTest(BaseTestCase):
 
-    def test_wb_get_device_removable_file_path(self):
+    @patch("os.path.islink")
+    def test_wb_get_device_removable_file_path(self, is_link_mock):
         """
         When passed a device in /dev, the L{_get_device_removable_file_path}
         function returns the corresponding removable file path in /sys/block.
@@ -115,15 +126,15 @@ class RemovableDiskTest(LandscapeTest):
         device = "/dev/sdb"
         expected = "/sys/block/sdb/removable"
 
-        is_link_mock = self.mocker.replace(os.path.islink)
-        is_link_mock(device)
-        self.mocker.result(False)
-        self.mocker.replay()
+        is_link_mock.return_value = False
 
         result = _get_device_removable_file_path(device)
+
+        is_link_mock.assert_called_once_with(device)
         self.assertEqual(expected, result)
 
-    def test_wb_get_device_removable_file_path_with_partition(self):
+    @patch("os.path.islink")
+    def test_wb_with_partition(self, is_link_mock):
         """
         When passed a device in /dev with a partition number, the
         L{_get_device_removable_file_path} function returns the corresponding
@@ -132,15 +143,15 @@ class RemovableDiskTest(LandscapeTest):
         device = "/dev/sdb1"
         expected = "/sys/block/sdb/removable"
 
-        is_link_mock = self.mocker.replace(os.path.islink)
-        is_link_mock(device)
-        self.mocker.result(False)
-        self.mocker.replay()
+        is_link_mock.return_value = False
 
         result = _get_device_removable_file_path(device)
+
+        is_link_mock.assert_called_once_with(device)
         self.assertEqual(expected, result)
 
-    def test_wb_get_device_removable_file_path_without_dev(self):
+    @patch("os.path.islink")
+    def test_wb_get_device_removable_file_path_without_dev(self, is_link_mock):
         """
         When passed a device name (not the whole path), the
         L{_get_device_removable_file_path} function returns the corresponding
@@ -149,15 +160,16 @@ class RemovableDiskTest(LandscapeTest):
         device = "sdb1"
         expected = "/sys/block/sdb/removable"
 
-        is_link_mock = self.mocker.replace(os.path.islink)
-        is_link_mock(device)
-        self.mocker.result(False)
-        self.mocker.replay()
+        is_link_mock.return_value = False
 
         result = _get_device_removable_file_path(device)
+
+        is_link_mock.assert_called_once_with(device)
         self.assertEqual(expected, result)
 
-    def test_wb_get_device_removable_file_path_with_symlink(self):
+    @patch("os.path.islink")
+    @patch("os.readlink")
+    def test_wb_with_symlink(self, readlink_mock, is_link_mock):
         """
         When the device path passed to L{_get_device_removable_file_path} is a
         symlink (it's the case when disks are mounted by uuid or by label),
@@ -166,21 +178,18 @@ class RemovableDiskTest(LandscapeTest):
         """
         device = "/dev/disk/by-uuid/8b2ec410-ebd2-49ec-bb3c-b8b13effab08"
 
-        readlink_mock = self.mocker.replace(os.readlink)
-        readlink_mock(device)
-        self.mocker.result("../../sda1")
-
-        is_link_mock = self.mocker.replace(os.path.islink)
-        is_link_mock(device)
-        self.mocker.result(True)
-
-        self.mocker.replay()
+        readlink_mock.return_value = "../../sda1"
+        is_link_mock.return_value = True
 
         expected = "/sys/block/sda/removable"
         result = _get_device_removable_file_path(device)
+
+        readlink_mock.assert_called_once_with(device)
+        is_link_mock.assert_called_once_with(device)
         self.assertEqual(expected, result)
 
-    def test_wb_get_device_removable_file_path_raid_device(self):
+    @patch("os.path.islink")
+    def test_wb_get_device_removable_file_path_raid_device(self, is_link_mock):
         """
         When passed a more exotic device file, like for example a raid device
         (e.g. /dev/cciss/c0d1p1), the L{_get_device_removable_file_path}
@@ -191,16 +200,14 @@ class RemovableDiskTest(LandscapeTest):
         # The expected path does not exists, but it doesn't matter here.
         expected = "/sys/block/c/removable"
 
-        is_link_mock = self.mocker.replace(os.path.islink)
-        is_link_mock(device)
-        self.mocker.result(False)
-
-        self.mocker.replay()
+        is_link_mock.return_value = False
 
         result = _get_device_removable_file_path(device)
+        is_link_mock.assert_called_once_with(device)
         self.assertEqual(expected, result)
 
-    def test_is_device_removable(self):
+    @patch("landscape.lib.disk._get_device_removable_file_path")
+    def test_is_device_removable(self, removable_mock):
         """
         Given the path to a file, determine if it means the device is removable
         or not.
@@ -208,14 +215,13 @@ class RemovableDiskTest(LandscapeTest):
         device = "/dev/sdb1"
         path = self.makeFile("1")
 
-        removable_mock = self.mocker.replace(_get_device_removable_file_path)
-        removable_mock(device)
-        self.mocker.result(path)
-        self.mocker.replay()
+        removable_mock.return_value = path
 
         self.assertTrue(is_device_removable(device))
+        removable_mock.assert_called_once_with(device)
 
-    def test_is_device_removable_false(self):
+    @patch("landscape.lib.disk._get_device_removable_file_path")
+    def test_is_device_removable_false(self, removable_mock):
         """
         Given the path to a file, determine if it means the device is removable
         or not.
@@ -223,14 +229,13 @@ class RemovableDiskTest(LandscapeTest):
         device = "/dev/sdb1"
         path = self.makeFile("0")
 
-        removable_mock = self.mocker.replace(_get_device_removable_file_path)
-        removable_mock(device)
-        self.mocker.result(path)
-        self.mocker.replay()
+        removable_mock.return_value = path
 
         self.assertFalse(is_device_removable(device))
+        removable_mock.assert_called_once_with(device)
 
-    def test_is_device_removable_garbage(self):
+    @patch("landscape.lib.disk._get_device_removable_file_path")
+    def test_is_device_removable_garbage(self, removable_mock):
         """
         Given the path to a file, determine if it means the device is removable
         or not.
@@ -238,40 +243,36 @@ class RemovableDiskTest(LandscapeTest):
         device = "/dev/sdb1"
         path = self.makeFile("Some garbage")
 
-        removable_mock = self.mocker.replace(_get_device_removable_file_path)
-        removable_mock(device)
-        self.mocker.result(path)
-        self.mocker.replay()
+        removable_mock.return_value = path
 
         self.assertFalse(is_device_removable(device))
+        removable_mock.assert_called_once_with(device)
 
-    def test_is_device_removable_path_doesnt_exist(self):
+    @patch("landscape.lib.disk._get_device_removable_file_path")
+    def test_is_device_removable_path_doesnt_exist(self, removable_mock):
         """
         When given a non-existing path, report the device as not removable.
         """
         device = "/dev/sdb1"
         path = "/what/ever"
 
-        removable_mock = self.mocker.replace(_get_device_removable_file_path)
-        removable_mock(device)
-        self.mocker.result(path)
-        self.mocker.replay()
+        removable_mock.return_value = path
 
         self.assertFalse(is_device_removable(device))
+        removable_mock.assert_called_once_with(device)
 
-    def test_is_removable_raid_device(self):
+    @patch("os.path.islink")
+    def test_is_removable_raid_device(self, is_link_mock):
         """
         When passed the path to a raid device (e.g. /dev/cciss/c0d0p0), the
         is_device_removable function returns False.
         """
         device = "/dev/cciss/c0d1p1"
 
-        is_link_mock = self.mocker.replace(os.path.islink)
-        is_link_mock(device)
-        self.mocker.result(False)
-        self.mocker.replay()
+        is_link_mock.return_value = False
 
         self.assertFalse(is_device_removable(device))
+        is_link_mock.assert_called_once_with(device)
 
     def test_is_device_removable_memory_card(self):
         """
