@@ -1,12 +1,12 @@
 import time
 import os
+import unittest
 
-from landscape.tests.helpers import LandscapeTest
-
+from landscape.lib import testing
 from landscape.lib.lock import lock_path, LockError
 
 
-class LockTest(LandscapeTest):
+class LockTest(testing.FSTestCase, unittest.TestCase):
 
     def setUp(self):
         super(LockTest, self).setUp()
@@ -28,4 +28,3 @@ class LockTest(LandscapeTest):
         started = time.time()
         self.assertRaises(LockError, lock_path, self.filename, timeout=0.5)
         self.assertTrue(started < time.time() - 0.5)
-        
