@@ -1,34 +1,37 @@
 import array
-from cStringIO import StringIO
 import socket
-from subprocess import Popen, PIPE
-from landscape.tests.helpers import LandscapeTest
+import unittest
 
+from mock import patch, ANY, mock_open
+from subprocess import Popen, PIPE
+
+from landscape.lib import testing
 from landscape.lib.network import (
     get_network_traffic, get_active_device_info, get_active_interfaces,
     get_fqdn, get_network_interface_speed)
-from landscape.tests.mocker import ANY
 
 
-class NetworkInfoTest(LandscapeTest):
+class BaseTestCase(testing.HelperTestCase, unittest.TestCase):
+    pass
 
-    def test_get_active_device_info(self):
+
+class NetworkInfoTest(BaseTestCase):
+
+    @patch("landscape.lib.network.get_network_interface_speed")
+    def test_get_active_device_info(self, mock_get_network_interface_speed):
         """
         Device info returns a sequence of information about active
         network devices, compare and verify the output against
         that returned by ifconfig.
         """
-        mock_get_network_interface_speed = self.mocker.replace(
-            get_network_interface_speed)
-        mock_get_network_interface_speed(ANY, ANY)
-        self.mocker.result((100, True))
-        self.mocker.count(min=1, max=None)
-        self.mocker.replay()
+        mock_get_network_interface_speed.return_value = (100, True)
 
         device_info = get_active_device_info()
-        result = Popen(["/sbin/ifconfig"], stdout=PIPE).communicate()[0]
+        process = Popen(
+            ["/sbin/ifconfig"], stdout=PIPE, env={"LC_ALL": "C"})
+        result = process.communicate()[0].decode("ascii")
         interface_blocks = dict(
-            [(block.split()[0], block.upper()) for block in
+            [(block.split()[0].strip(":"), block.upper()) for block in
              filter(None, result.split("\n\n"))])
 
         for device in device_info:
@@ -52,35 +55,37 @@ class NetworkInfoTest(LandscapeTest):
             self.assertEqual(100, device["speed"])
             self.assertEqual(True, device["duplex"])
 
+        self.assertTrue(mock_get_network_interface_speed.call_count >= 1)
+        mock_get_network_interface_speed.assert_called_with(ANY, ANY)
+
     def test_skip_loopback(self):
         """The C{lo} interface is not reported by L{get_active_device_info}."""
         device_info = get_active_device_info()
         interfaces = [i["interface"] for i in device_info]
         self.assertNotIn("lo", interfaces)
 
-    def test_skip_vlan(self):
+    @patch("landscape.lib.network.get_active_interfaces")
+    def test_skip_vlan(self, mock_get_active_interfaces):
         """VLAN interfaces are not reported by L{get_active_device_info}."""
-        mock_get_active_interfaces = self.mocker.replace(get_active_interfaces)
-        mock_get_active_interfaces(ANY)
-        self.mocker.passthrough(
-            result_callback=lambda result: list(result) + ["eth0.1"])
-        self.mocker.replay()
+        mock_get_active_interfaces.side_effect = lambda sock: (
+            list(get_active_interfaces(sock)) + [b"eth0.1"])
         device_info = get_active_device_info()
+        mock_get_active_interfaces.assert_called_with(ANY)
         interfaces = [i["interface"] for i in device_info]
         self.assertNotIn("eth0.1", interfaces)
 
-    def test_skip_alias(self):
+    @patch("landscape.lib.network.get_active_interfaces")
+    def test_skip_alias(self, mock_get_active_interfaces):
         """Interface aliases are not reported by L{get_active_device_info}."""
-        mock_get_active_interfaces = self.mocker.replace(get_active_interfaces)
-        mock_get_active_interfaces(ANY)
-        self.mocker.passthrough(
-            result_callback=lambda result: list(result) + ["eth0:foo"])
-        self.mocker.replay()
+        mock_get_active_interfaces.side_effect = lambda sock: (
+            list(get_active_interfaces(sock)) + [b"eth0:foo"])
         device_info = get_active_device_info()
         interfaces = [i["interface"] for i in device_info]
         self.assertNotIn("eth0:foo", interfaces)
 
-    def test_duplicate_network_interfaces(self):
+    @patch("struct.unpack")
+    @patch("fcntl.ioctl")
+    def test_duplicate_network_interfaces(self, mock_ioctl, mock_unpack):
         """
         L{get_active_interfaces} doesn't return duplicate network interfaces.
         The call to C{fcntl.ioctl} might return the same interface several
@@ -95,57 +100,57 @@ class NetworkInfoTest(LandscapeTest):
         # This is a fake response observed to return the same interface several
         # times (here, br1:priv)
         response = (
-            "lo\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02"
-            "\x00\x00\x00\x7f\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00"
-            "\x00\x00\x00\x00\x00\x00\x00eth1:pub\x00\x00\x00\x00\x00\x00\x00"
-            "\x00\x02\x00\x00\x00\xc8\xb4\xc4.\x00\x00\x00\x00\x00\x00\x00\x00"
-            "\x00\x00\x00\x00\x00\x00\x00\x00br1:metadata\x00\x00\x00\x00\x02"
-            "\x00\x00\x00\xa9\xfe\xa9\xfe\x00\x00\x00\x00\x00\x00\x00\x00\x00"
-            "\x00\x00\x00\x00\x00\x00\x00br1:0\x00\x00\x00\x00\x00\x00\x00\x00"
-            "\x00\x00\x00\x02\x00\x00\x00\xc9\x19\x1f\x1d\x00\x00\x00\x00\x00"
-            "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00br1\x00\x00\x00\x00"
-            "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00\x00\x00\xc0\xa8d"
-            "\x1d\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
-            "\x00br1:priv\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00\x00\x00\xac"
-            "\x13\x02\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
-            "\x00\x00\x00br1:priv\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00\x00"
-            "\x00\xac\x13\x02A")
+            b"lo\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02"
+            b"\x00\x00\x00\x7f\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00"
+            b"\x00\x00\x00\x00\x00\x00\x00eth1:pub\x00\x00\x00\x00\x00\x00\x00"
+            b"\x00\x02\x00\x00\x00\xc8\xb4\xc4.\x00\x00\x00\x00\x00\x00\x00"
+            b"\x00"
+            b"\x00\x00\x00\x00\x00\x00\x00\x00br1:metadata\x00\x00\x00\x00\x02"
+            b"\x00\x00\x00\xa9\xfe\xa9\xfe\x00\x00\x00\x00\x00\x00\x00\x00\x00"
+            b"\x00\x00\x00\x00\x00\x00\x00br1:0\x00\x00\x00\x00\x00\x00\x00"
+            b"\x00"
+            b"\x00\x00\x00\x02\x00\x00\x00\xc9\x19\x1f\x1d\x00\x00\x00\x00\x00"
+            b"\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00br1\x00\x00\x00\x00"
+            b"\x00\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00\x00\x00\xc0\xa8d"
+            b"\x1d\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
+            b"\x00br1:priv\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00\x00\x00\xac"
+            b"\x13\x02\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
+            b"\x00\x00\x00br1:priv\x00\x00\x00\x00\x00\x00\x00\x00\x02\x00\x00"
+            b"\x00\xac\x13\x02A")
 
-        fake_array = array.array("B", response + "\0" * 4855)
-        mock_array = self.mocker.replace("array")
-        mock_array.array("B", ANY)
-        self.mocker.result(fake_array)
+        fake_array = array.array("B", response + b"\0" * 4855)
 
-        mock_ioctl = self.mocker.replace("fcntl")
-        mock_ioctl.ioctl(ANY, ANY, ANY)
-        self.mocker.result(0)
+        with patch("array.array") as mock_array:
+            mock_array.return_value = fake_array
+            mock_ioctl.return_value = 0
+            mock_unpack.return_value = (280, 38643456)
 
-        mock_unpack = self.mocker.replace("struct")
-        mock_unpack.unpack("iL", ANY)
-        self.mocker.result((280, 38643456))
+            sock = socket.socket(
+                socket.AF_INET, socket.SOCK_DGRAM, socket.IPPROTO_IP)
+            interfaces = list(get_active_interfaces(sock))
 
-        self.mocker.replay()
+        mock_array.assert_called_with("B", ANY)
+        mock_ioctl.assert_called_with(ANY, ANY, ANY)
+        mock_unpack.assert_called_with("iL", ANY)
 
-        sock = socket.socket(
-            socket.AF_INET, socket.SOCK_DGRAM, socket.IPPROTO_IP)
         self.assertEqual(
-            ["lo", "eth1:pub", "br1:metadata", "br1:0", "br1", "br1:priv"],
-            list(get_active_interfaces(sock)))
+            [b"lo", b"eth1:pub", b"br1:metadata",
+             b"br1:0", b"br1", b"br1:priv"],
+            interfaces)
 
     def test_get_network_traffic(self):
         """
         Network traffic is assessed via reading /proc/net/dev, verify
         the parsed output against a known sample.
         """
-        open_mock = self.mocker.replace("__builtin__.open")
-        open_mock("/proc/net/dev", "r")
-        self.mocker.result(StringIO(test_proc_net_dev_output))
-        self.mocker.replay()
-        traffic = get_network_traffic()
+        m = mock_open(read_data=test_proc_net_dev_output)
+        with patch('landscape.lib.network.open', m):
+            traffic = get_network_traffic()
+        m.assert_called_with("/proc/net/dev", "r")
         self.assertEqual(traffic, test_proc_net_dev_parsed)
 
 
-#exact output of cat /proc/net/dev snapshot with line continuations for pep8
+# exact output of cat /proc/net/dev snapshot with line continuations for pep8
 test_proc_net_dev_output = """\
 Inter-|   Receive                                                |  Transmit
  face |bytes    packets errs drop fifo frame compressed multicast|bytes    \
@@ -158,40 +163,40 @@ Inter-|   Receive                                                |  Transmit
 
 test_proc_net_dev_parsed = {
     "lo": {"recv_bytes": 3272627934,
-          "recv_packets": 3321049,
-          "recv_errs": 0,
-          "recv_drop": 0,
-          "recv_fifo": 0,
-          "recv_frame": 0,
-          "recv_compressed": 0,
-          "recv_multicast": 0,
-          "send_bytes": 3272627934,
-          "send_packets": 3321049,
-          "send_errs": 0,
-          "send_drop": 0,
-          "send_fifo": 0,
-          "send_colls": 0,
-          "send_carrier": 0,
-          "send_compressed": 0},
+           "recv_packets": 3321049,
+           "recv_errs": 0,
+           "recv_drop": 0,
+           "recv_fifo": 0,
+           "recv_frame": 0,
+           "recv_compressed": 0,
+           "recv_multicast": 0,
+           "send_bytes": 3272627934,
+           "send_packets": 3321049,
+           "send_errs": 0,
+           "send_drop": 0,
+           "send_fifo": 0,
+           "send_colls": 0,
+           "send_carrier": 0,
+           "send_compressed": 0},
     "eth0": {"recv_bytes": 6063748,
-            "recv_packets": 12539,
-            "recv_errs": 0,
-            "recv_drop": 0,
-            "recv_fifo": 0,
-            "recv_frame": 0,
-            "recv_compressed": 0,
-            "recv_multicast": 62,
-            "send_bytes": 2279693,
-            "send_packets": 12579,
-            "send_errs": 0,
-            "send_drop": 0,
-            "send_fifo": 0,
-            "send_colls": 19,
-            "send_carrier": 0,
-            "send_compressed": 0}}
+             "recv_packets": 12539,
+             "recv_errs": 0,
+             "recv_drop": 0,
+             "recv_fifo": 0,
+             "recv_frame": 0,
+             "recv_compressed": 0,
+             "recv_multicast": 62,
+             "send_bytes": 2279693,
+             "send_packets": 12579,
+             "send_errs": 0,
+             "send_drop": 0,
+             "send_fifo": 0,
+             "send_colls": 19,
+             "send_carrier": 0,
+             "send_compressed": 0}}
 
 
-class FQDNTest(LandscapeTest):
+class FQDNTest(BaseTestCase):
 
     def test_default_fqdn(self):
         """
@@ -212,48 +217,47 @@ class FQDNTest(LandscapeTest):
         self.assertNotIn("localhost", get_fqdn())
 
 
-class NetworkInterfaceSpeedTest(LandscapeTest):
+class NetworkInterfaceSpeedTest(BaseTestCase):
 
-    def test_get_network_interface_speed(self):
+    @patch("struct.unpack")
+    @patch("fcntl.ioctl")
+    def test_get_network_interface_speed(self, mock_ioctl, mock_unpack):
         """
         The link speed is reported as unpacked from the ioctl() call.
         """
         sock = socket.socket(
             socket.AF_INET, socket.SOCK_DGRAM, socket.IPPROTO_IP)
         # ioctl always succeeds
-        mock_ioctl = self.mocker.replace("fcntl")
-        mock_ioctl.ioctl(ANY, ANY, ANY)
-        self.mocker.result(0)
+        mock_unpack.return_value = (100, False)
 
-        mock_unpack = self.mocker.replace("struct")
-        mock_unpack.unpack("12xHB28x", ANY)
-        self.mocker.result((100, False))
+        result = get_network_interface_speed(sock, b"eth0")
 
-        self.mocker.replay()
+        mock_ioctl.assert_called_with(ANY, ANY, ANY)
+        mock_unpack.assert_called_with("12xHB28x", ANY)
 
-        self.assertEqual((100, False),
-                         get_network_interface_speed(sock, "eth0"))
+        self.assertEqual((100, False), result)
 
-    def test_get_network_interface_speed_unplugged(self):
+    @patch("struct.unpack")
+    @patch("fcntl.ioctl")
+    def test_unplugged(self, mock_ioctl, mock_unpack):
         """
         The link speed for an unplugged interface is reported as 0.
         """
         sock = socket.socket(
             socket.AF_INET, socket.SOCK_DGRAM, socket.IPPROTO_IP)
+
         # ioctl always succeeds
-        mock_ioctl = self.mocker.replace("fcntl")
-        mock_ioctl.ioctl(ANY, ANY, ANY)
-        self.mocker.result((0, False))
+        mock_unpack.return_value = (65535, False)
 
-        mock_unpack = self.mocker.replace("struct")
-        mock_unpack.unpack("12xHB28x", ANY)
-        self.mocker.result((65535, False))
+        result = get_network_interface_speed(sock, b"eth0")
 
-        self.mocker.replay()
+        mock_ioctl.assert_called_with(ANY, ANY, ANY)
+        mock_unpack.assert_called_with("12xHB28x", ANY)
 
-        self.assertEqual((0, False), get_network_interface_speed(sock, "eth0"))
+        self.assertEqual((0, False), result)
 
-    def test_get_network_interface_speed_not_supported(self):
+    @patch("fcntl.ioctl")
+    def test_get_network_interface_speed_not_supported(self, mock_ioctl):
         """
         Some drivers do not report the needed interface speed. In this case
         an C{IOError} with errno 95 is raised ("Operation not supported").
@@ -266,16 +270,16 @@ class NetworkInterfaceSpeedTest(LandscapeTest):
         theerror.message = "Operation not supported"
 
         # ioctl always raises
-        mock_ioctl = self.mocker.replace("fcntl")
-        mock_ioctl.ioctl(ANY, ANY, ANY)
-        self.mocker.throw(theerror)
+        mock_ioctl.side_effect = theerror
 
-        self.mocker.replay()
+        result = get_network_interface_speed(sock, b"eth0")
 
-        self.assertEqual((-1, False),
-                         get_network_interface_speed(sock, "eth0"))
+        mock_ioctl.assert_called_with(ANY, ANY, ANY)
 
-    def test_get_network_interface_speed_not_permitted(self):
+        self.assertEqual((-1, False), result)
+
+    @patch("fcntl.ioctl")
+    def test_get_network_interface_speed_not_permitted(self, mock_ioctl):
         """
         In some cases (lucid seems to be affected), the ioctl() call is not
         allowed for non-root users. In that case we intercept the error and
@@ -288,16 +292,16 @@ class NetworkInterfaceSpeedTest(LandscapeTest):
         theerror.message = "Operation not permitted"
 
         # ioctl always raises
-        mock_ioctl = self.mocker.replace("fcntl")
-        mock_ioctl.ioctl(ANY, ANY, ANY)
-        self.mocker.throw(theerror)
+        mock_ioctl.side_effect = theerror
 
-        self.mocker.replay()
+        result = get_network_interface_speed(sock, b"eth0")
 
-        self.assertEqual((-1, False),
-                         get_network_interface_speed(sock, "eth0"))
+        mock_ioctl.assert_called_with(ANY, ANY, ANY)
 
-    def test_get_network_interface_speed_other_io_error(self):
+        self.assertEqual((-1, False), result)
+
+    @patch("fcntl.ioctl")
+    def test_get_network_interface_speed_other_io_error(self, mock_ioctl):
         """
         In case we get an IOError that is not "Operation not permitted", the
         exception should be raised.
@@ -309,10 +313,6 @@ class NetworkInterfaceSpeedTest(LandscapeTest):
         theerror.message = "Whatever"
 
         # ioctl always raises
-        mock_ioctl = self.mocker.replace("fcntl")
-        mock_ioctl.ioctl(ANY, ANY, ANY)
-        self.mocker.throw(theerror)
+        mock_ioctl.side_effect = theerror
 
-        self.mocker.replay()
-
-        self.assertRaises(IOError, get_network_interface_speed, sock, "eth0")
+        self.assertRaises(IOError, get_network_interface_speed, sock, b"eth0")
