@@ -1,13 +1,14 @@
-import pprint
 import os
+import pprint
+import unittest
 
+from landscape.lib import testing
 from landscape.lib.persist import (
     path_string_to_tuple, path_tuple_to_string, Persist, RootedPersist,
     PickleBackend, PersistError, PersistReadOnlyError)
-from landscape.tests.helpers import LandscapeTest
 
 
-class PersistHelpersTest(LandscapeTest):
+class PersistHelpersTest(unittest.TestCase):
 
     paths = [
         ("ab", ("ab",)),
@@ -32,7 +33,7 @@ class PersistHelpersTest(LandscapeTest):
             self.assertEqual(path_tuple_to_string(path_tuple), path_string)
 
 
-class BasePersistTest(LandscapeTest):
+class BasePersistTest(unittest.TestCase):
 
     set_items = [
         ("ab", 1),
@@ -61,8 +62,8 @@ class BasePersistTest(LandscapeTest):
                                 "op": [0, 1, 2]
                                },
                          },
-                   "qr": {"s": {"t": "u"}},
-                   "v": [0, {"v": "woot"}, 2],
+                  "qr": {"s": {"t": "u"}},
+                  "v": [0, {"v": "woot"}, 2],
                  }
 
     get_items = [
@@ -103,12 +104,12 @@ class BasePersistTest(LandscapeTest):
                  }
 
     def setUp(self):
-        LandscapeTest.setUp(self)
+        super(BasePersistTest, self).setUp()
         self.persist = self.build_persist()
 
     def tearDown(self):
         del self.persist
-        LandscapeTest.tearDown(self)
+        super(BasePersistTest, self).tearDown()
 
     def build_persist(self, *args, **kwargs):
         return Persist(*args, **kwargs)
@@ -275,7 +276,10 @@ class GeneralPersistTest(BasePersistTest):
         self.assertEqual(self.persist.get("my-module.option"), 1)
 
 
-class SaveLoadPersistTest(BasePersistTest):
+class SaveLoadPersistTest(testing.FSTestCase, BasePersistTest):
+
+    def makePersistFile(self, *args, **kwargs):
+        return self.makeFile(*args, backupsuffix=".old", **kwargs)
 
     def test_readonly(self):
         self.assertFalse(self.persist.readonly)
@@ -324,7 +328,7 @@ class SaveLoadPersistTest(BasePersistTest):
         for path in self.set_result:
             self.persist.set(path, self.set_result[path])
 
-        filename = self.makeFile()
+        filename = self.makePersistFile()
         self.persist.save(filename)
 
         persist = self.build_persist()
@@ -335,7 +339,7 @@ class SaveLoadPersistTest(BasePersistTest):
                          self.format(result, self.set_result))
 
     def test_save_on_unexistent_dir(self):
-        dirname = self.makeFile()
+        dirname = self.makePersistFile()
         filename = os.path.join(dirname, "foobar")
 
         self.assertFalse(os.path.exists(dirname))
@@ -355,7 +359,7 @@ class SaveLoadPersistTest(BasePersistTest):
         Persist can be constructed with a filename, and Persist.save with no
         arguments will write to that filename.
         """
-        filename = self.makeFile()
+        filename = self.makePersistFile()
         persist = self.build_persist(filename=filename)
         self.assertFalse(os.path.exists(filename))
         persist.save()
@@ -373,7 +377,7 @@ class SaveLoadPersistTest(BasePersistTest):
         If a Persist is created with a default filename, and the filename
         exists, it will be loaded.
         """
-        filename = self.makeFile()
+        filename = self.makePersistFile()
         persist = self.build_persist(filename=filename)
         persist.set("foo", "bar")
         persist.save()
@@ -394,7 +398,7 @@ class SaveLoadPersistTest(BasePersistTest):
         self.assertEqual(persist.get("a"), 1)
 
     def test_load_empty_files_wont_break(self):
-        filename = self.makeFile("")
+        filename = self.makePersistFile("")
         self.persist.load(filename)
 
     def test_load_empty_files_restore_backup(self):
@@ -402,7 +406,7 @@ class SaveLoadPersistTest(BasePersistTest):
         If the current file is empty, it tries to load the old one if it
         exists.
         """
-        filename = self.makeFile("")
+        filename = self.makePersistFile("")
         filename_old = filename + ".old"
 
         self.persist.set("a", 1)
@@ -425,7 +429,7 @@ class SaveLoadPersistTest(BasePersistTest):
         If the file doesn't exist, it tries to load the old one if present and
         valid.
         """
-        filename = self.makeFile("")
+        filename = self.makePersistFile("")
         filename_old = filename + ".old"
         os.unlink(filename)
 
