@@ -1,13 +1,13 @@
-import unittest
+import mock
 import os
+import unittest
 
-from landscape.tests.helpers import LandscapeTest
-
+from landscape.lib import testing
 from landscape.lib.process import calculate_pcpu, ProcessInformation
-from landscape.lib.fs import create_file
+from landscape.lib.fs import create_text_file
 
 
-class ProcessInfoTest(LandscapeTest):
+class ProcessInfoTest(testing.FSTestCase, unittest.TestCase):
 
     def setUp(self):
         super(ProcessInfoTest, self).setUp()
@@ -24,7 +24,7 @@ class ProcessInfoTest(LandscapeTest):
         os.mkdir(process_dir)
 
         cmd_line = "/usr/bin/foo"
-        create_file(os.path.join(process_dir, "cmdline"), cmd_line)
+        create_text_file(os.path.join(process_dir, "cmdline"), cmd_line)
 
         status = "\n".join([
             "Name: foo",
@@ -33,21 +33,22 @@ class ProcessInfoTest(LandscapeTest):
             "Gid: 2000",
             "VmSize: 3000",
             "Ignored: value"])
-        create_file(os.path.join(process_dir, "status"), status)
+        create_text_file(os.path.join(process_dir, "status"), status)
 
         stat_array = [str(index) for index in range(44)]
         stat = " ".join(stat_array)
-        create_file(os.path.join(process_dir, "stat"), stat)
+        create_text_file(os.path.join(process_dir, "stat"), stat)
 
-    def test_missing_process_race(self):
+    @mock.patch("landscape.lib.process.detect_jiffies", return_value=1)
+    @mock.patch("os.listdir")
+    @mock.patch("landscape.lib.sysstats.get_uptime")
+    def test_missing_process_race(self, get_uptime_mock, list_dir_mock,
+                                  jiffies_mock):
         """
         We use os.listdir("/proc") to get the list of active processes, if a
         process ends before we attempt to read the process' information, then
         this should not trigger an error.
         """
-        listdir_mock = self.mocker.replace("os.listdir")
-        listdir_mock("/proc")
-        self.mocker.result(["12345"])
 
         class FakeFile(object):
 
@@ -67,20 +68,22 @@ class ProcessInfoTest(LandscapeTest):
             def close(self):
                 self.closed = True
 
-        open_mock = self.mocker.replace("__builtin__.open")
-        open_mock("/proc/12345/cmdline", "r")
+        list_dir_mock.return_value = ["12345"]
+        get_uptime_mock.return_value = 1.0
         fakefile1 = FakeFile("test-binary")
-        self.mocker.result(fakefile1)
-
-        open_mock("/proc/12345/status", "r")
         fakefile2 = FakeFile(None)
-        self.mocker.result(fakefile2)
-
-        self.mocker.replay()
-
-        process_info = ProcessInformation("/proc")
-        processes = list(process_info.get_all_process_info())
+        with mock.patch(
+                "landscape.lib.process.open", mock.mock_open()) as open_mock:
+            # This means "return fakefile1, then fakefile2"
+            open_mock.side_effect = [fakefile1, fakefile2]
+            process_info = ProcessInformation("/proc")
+            processes = list(process_info.get_all_process_info())
+            calls = [
+                mock.call("/proc/12345/cmdline", "r"),
+                mock.call("/proc/12345/status", "r")]
+            open_mock.assert_has_calls(calls)
         self.assertEqual(processes, [])
+        list_dir_mock.assert_called_with("/proc")
         self.assertTrue(fakefile1.closed)
         self.assertTrue(fakefile2.closed)
 
@@ -92,7 +95,7 @@ class ProcessInfoTest(LandscapeTest):
         self._add_process_info(12, state="A (some state)")
         process_info = ProcessInformation(self.proc_dir)
         info = process_info.get_process_info(12)
-        self.assertEqual("A", info["state"])
+        self.assertEqual(b"A", info["state"])
 
     def test_get_process_info_state_preserves_case(self):
         """
@@ -102,7 +105,7 @@ class ProcessInfoTest(LandscapeTest):
         self._add_process_info(12, state="a (some state)")
         process_info = ProcessInformation(self.proc_dir)
         info = process_info.get_process_info(12)
-        self.assertEqual("a", info["state"])
+        self.assertEqual(b"a", info["state"])
 
     def test_get_process_info_state_tracing_stop_lucid(self):
         """
@@ -116,8 +119,8 @@ class ProcessInfoTest(LandscapeTest):
         process_info = ProcessInformation(self.proc_dir)
         info1 = process_info.get_process_info(12)
         info2 = process_info.get_process_info(12)
-        self.assertEqual("t", info1["state"])
-        self.assertEqual("t", info2["state"])
+        self.assertEqual(b"t", info1["state"])
+        self.assertEqual(b"t", info2["state"])
 
 
 class CalculatePCPUTest(unittest.TestCase):
