@@ -3,24 +3,21 @@ Network introspection utilities using ioctl and the /proc filesystem.
 """
 import os
 
-from landscape.lib.fs import read_file
+from landscape.lib.fs import read_text_file
 
 
 def get_vm_info(root_path="/"):
     """
-    Return a string with the virtualization type if it's known, an empty string
-    otherwise.
+    Return a bytestring with the virtualization type if it's known, an empty
+    bytestring otherwise.
 
-    It loops through some possible configurations and return a string with
+    It loops through some possible configurations and return a bytestring with
     the name of the technology being used or None if there's no match
     """
-    def join_root_path(path):
-        return os.path.join(root_path, path)
-
     if _is_vm_openvz(root_path):
-        return "openvz"
+        return b"openvz"
     if _is_vm_xen(root_path):
-        return "xen"
+        return b"xen"
 
     sys_vendor_path = os.path.join(root_path, "sys/class/dmi/id/sys_vendor")
     if os.path.exists(sys_vendor_path):
@@ -37,22 +34,14 @@ def get_container_info(run_path="/run"):
     for filename in ("container_type", "systemd/container"):
         path = os.path.join(run_path, filename)
         if os.path.exists(path):
-            return read_file(path).strip()
+            return read_text_file(path).strip()
     return ""
 
 
 def _is_vm_xen(root_path):
     """Check if the host is virtualized with Xen."""
-    xen_paths = [
-        os.path.join(root_path, path)
-        for path in ("proc/sys/xen", "proc/xen")]
-
-    if filter(os.path.exists, xen_paths):
-        return True
-
-    # /sys/bus/xen exists on most machines, but only virtual machines have
-    # devices
     sys_xen_path = os.path.join(root_path, "sys/bus/xen/devices")
+    # Paravirtualized and HVM instances have device links under the directory
     return os.path.isdir(sys_xen_path) and os.listdir(sys_xen_path)
 
 
@@ -62,32 +51,39 @@ def _is_vm_openvz(root_path):
 
 
 def _get_vm_by_vendor(sys_vendor_path):
-    """Return the VM type string (possibly empty) based on the vendor."""
-    vendor = read_file(sys_vendor_path).lower()
+    """Return the VM type byte string (possibly empty) based on the vendor."""
+    vendor = read_text_file(sys_vendor_path).lower()
     # Use lower-key string for vendors, since we do case-insentive match.
+    # We need bytes here as required by the message schema.
+
+    # 2018-01: AWS and DO are now returning custom sys_vendor names
+    # instead of qemu. If this becomes a trend, it may be worth also checking
+    # dmi/id/chassis_vendor which seems to unchanged (bochs).
     content_vendors_map = (
-        ("bochs", "kvm"),
-        ("google", "gce"),
-        ("innotek", "virtualbox"),
-        ("microsoft", "hyperv"),
-        ("openstack", "kvm"),
-        ("qemu", "kvm"),
-        ("vmware", "vmware"))
+        ("amazon ec2", b"kvm"),
+        ("bochs", b"kvm"),
+        ("digitalocean", b"kvm"),
+        ("google", b"gce"),
+        ("innotek", b"virtualbox"),
+        ("microsoft", b"hyperv"),
+        ("openstack", b"kvm"),
+        ("qemu", b"kvm"),
+        ("vmware", b"vmware"))
     for name, vm_type in content_vendors_map:
         if name in vendor:
             return vm_type
 
-    return ""
+    return b""
 
 
 def _get_vm_legacy(root_path):
     """Check if the host is virtualized looking at /proc/cpuinfo content."""
     try:
-        cpuinfo = read_file(os.path.join(root_path, "proc/cpuinfo"))
+        cpuinfo = read_text_file(os.path.join(root_path, "proc/cpuinfo"))
     except (IOError, OSError):
-        return ""
+        return b""
 
     if "qemu" in cpuinfo:
-        return "kvm"
+        return b"kvm"
 
-    return ""
+    return b""
