@@ -7,7 +7,8 @@ from logging.handlers import RotatingFileHandler
 from twisted.python.reflect import namedClass
 from twisted.internet.defer import Deferred, maybeDeferred
 
-from landscape.deployment import BaseConfiguration
+from landscape import VERSION
+from landscape.lib.config import BaseConfiguration
 from landscape.sysinfo.sysinfo import SysInfoPluginRegistry, format_sysinfo
 
 
@@ -18,13 +19,21 @@ ALL_PLUGINS = ["Load", "Disk", "Memory", "Temperature", "Processes",
 class SysInfoConfiguration(BaseConfiguration):
     """Specialized configuration for the Landscape sysinfo tool."""
 
+    version = VERSION
+
     default_config_filenames = ("/etc/landscape/client.conf",)
     if os.getuid() != 0:
         default_config_filenames += (
             os.path.expanduser("~/.landscape/sysinfo.conf"),)
+    default_data_dir = "/var/lib/landscape/client/"
 
     config_section = "sysinfo"
 
+    def __init__(self):
+        super(SysInfoConfiguration, self).__init__()
+
+        self._command_line_defaults["config"] = None
+
     def make_parser(self):
         """
         Specialize L{Configuration.make_parser}, adding any
@@ -94,19 +103,21 @@ def run(args, reactor=None, sysinfo=None):
     """
     try:
         setup_logging()
-    except IOError, e:
+    except IOError as e:
         sys.exit("Unable to setup logging. %s" % e)
 
     if sysinfo is None:
         sysinfo = SysInfoPluginRegistry()
     config = SysInfoConfiguration()
-    config.load(args)
+    # landscape-sysinfo needs to work where there's no
+    # /etc/landscape/client.conf See lp:1293990
+    config.load(args, accept_nonexistent_default_config=True)
     for plugin in config.get_plugins():
         sysinfo.add(plugin)
 
     def show_output(result):
-        print format_sysinfo(sysinfo.get_headers(), sysinfo.get_notes(),
-                             sysinfo.get_footnotes(), indent="  ")
+        print(format_sysinfo(sysinfo.get_headers(), sysinfo.get_notes(),
+                             sysinfo.get_footnotes(), indent="  "))
 
     def run_sysinfo():
         return sysinfo.run().addCallback(show_output)
