@@ -5,9 +5,9 @@ import os
 
 from twisted.python.failure import Failure
 
-from landscape.lib.twisted_util import gather_results
 from landscape.lib.log import log_failure
-from landscape.plugin import PluginRegistry
+from landscape.lib.plugin import PluginRegistry
+from landscape.lib.twisted_util import gather_results
 
 
 class SysInfoPluginRegistry(PluginRegistry):
@@ -97,7 +97,7 @@ class SysInfoPluginRegistry(PluginRegistry):
         for plugin in self.get_plugins():
             try:
                 result = plugin.run()
-            except:
+            except Exception:
                 self._log_plugin_error(Failure(), plugin)
             else:
                 result.addErrback(self._log_plugin_error, plugin)
@@ -151,7 +151,7 @@ def format_sysinfo(headers=(), notes=(), footnotes=(), width=80, indent="",
     # and then we go back from there until we can fit things.
     min_length = width
     for header, value in headers:
-        min_length = min(min_length, len(header)+len(value)+2) # 2 for ": "
+        min_length = min(min_length, len(header)+len(value)+2)  # 2 for ": "
     columns = int(math.ceil(float(width) /
                             (min_length + len(column_separator))))
 
@@ -205,7 +205,6 @@ def format_sysinfo(headers=(), notes=(), footnotes=(), width=80, indent="",
         # Otherwise, do the whole thing again with one less column.
         columns -= 1
 
-
     # Alright! Show time! Let's build the headers line by line.
     lines = []
     for row in range(headers_per_column):
