@@ -1,11 +1,14 @@
-import os
-
 from logging.handlers import RotatingFileHandler
 from logging import getLogger
+import os
+import unittest
 
+import mock
 from twisted.internet.defer import Deferred
 
-from landscape.lib.fs import create_file
+from landscape.lib.fs import create_text_file
+from landscape.lib.testing import (
+        ConfigTestCase, TwistedTestCase, HelperTestCase, StandardIOHelper)
 
 from landscape.sysinfo.deployment import (
     SysInfoConfiguration, ALL_PLUGINS, run, setup_logging,
@@ -14,11 +17,8 @@ from landscape.sysinfo.testplugin import TestPlugin
 from landscape.sysinfo.sysinfo import SysInfoPluginRegistry
 from landscape.sysinfo.load import Load
 
-from landscape.tests.helpers import LandscapeTest, StandardIOHelper
-from landscape.tests.mocker import ARGS, KWARGS
 
-
-class DeploymentTest(LandscapeTest):
+class DeploymentTest(ConfigTestCase, unittest.TestCase):
 
     def setUp(self):
         super(DeploymentTest, self).setUp()
@@ -51,7 +51,7 @@ class DeploymentTest(LandscapeTest):
 
     def test_config_file(self):
         filename = self.makeFile()
-        create_file(filename, "[sysinfo]\nsysinfo_plugins = TestPlugin\n")
+        create_text_file(filename, "[sysinfo]\nsysinfo_plugins = TestPlugin\n")
         self.configuration.load(["--config", filename, "-d", self.makeDir()])
         plugins = self.configuration.get_plugins()
         self.assertEqual(len(plugins), 1)
@@ -60,9 +60,9 @@ class DeploymentTest(LandscapeTest):
 
 class FakeReactor(object):
     """
-    Something that's easier to understand and more reusable than a bunch of
-    mocker
+    Something that's simpler and more reusable than a bunch of mocked objects.
     """
+
     def __init__(self):
         self.queued_calls = []
         self.scheduled_calls = []
@@ -81,7 +81,8 @@ class FakeReactor(object):
         self.running = False
 
 
-class RunTest(LandscapeTest):
+class RunTest(HelperTestCase, ConfigTestCase, TwistedTestCase,
+              unittest.TestCase):
 
     helpers = [StandardIOHelper]
 
@@ -109,38 +110,42 @@ class RunTest(LandscapeTest):
         self.assertEqual(sysinfo.get_notes(), ["Test note"])
         self.assertEqual(sysinfo.get_footnotes(), ["Test footnote"])
 
-    def test_format_sysinfo_gets_correct_information(self):
-        format_sysinfo = self.mocker.replace("landscape.sysinfo.sysinfo."
-                                             "format_sysinfo")
-        format_sysinfo([("Test header", "Test value")],
-                       ["Test note"], ["Test footnote"],
-                       indent="  ")
-        format_sysinfo(ARGS, KWARGS)
-        self.mocker.count(0)
-        self.mocker.replay()
-
+    @mock.patch("landscape.sysinfo.deployment.format_sysinfo")
+    def test_format_sysinfo_gets_correct_information(self, format_sysinfo):
         run(["--sysinfo-plugins", "TestPlugin"])
+        format_sysinfo.assert_called_once_with(
+            [("Test header", "Test value")],
+            ["Test note"], ["Test footnote"],
+            indent="  ")
 
     def test_format_sysinfo_output_is_printed(self):
-        format_sysinfo = self.mocker.replace("landscape.sysinfo.sysinfo."
-                                             "format_sysinfo")
-        format_sysinfo(ARGS, KWARGS)
-        self.mocker.result("Hello there!")
-        self.mocker.replay()
-
-        run(["--sysinfo-plugins", "TestPlugin"])
+        with mock.patch(
+                "landscape.sysinfo.deployment.format_sysinfo",
+                return_value="Hello there!") as format_sysinfo:
+            run(["--sysinfo-plugins", "TestPlugin"])
 
+        self.assertTrue(format_sysinfo.called)
         self.assertEqual(self.stdout.getvalue(), "Hello there!\n")
 
     def test_output_is_only_displayed_once_deferred_fires(self):
         deferred = Deferred()
-        sysinfo = self.mocker.patch(SysInfoPluginRegistry)
-        sysinfo.run()
-        self.mocker.passthrough()
-        self.mocker.result(deferred)
-        self.mocker.replay()
 
-        run(["--sysinfo-plugins", "TestPlugin"])
+        # We mock the sysinfo.run() to return a Deferred but still
+        # run the actual sysinfo.run() to gather the results from all
+        # the plugins.  We cannot easily combine return_value and
+        # side_effect because side_effect operates on the return_value,
+        # thus firing the callback and writing sysinfo out to stdout.
+        sysinfo = SysInfoPluginRegistry()
+        original_sysinfo_run = sysinfo.run
+
+        def wrapped_sysinfo_run(*args, **kwargs):
+            original_sysinfo_run(*args, **kwargs)
+            return deferred
+        sysinfo.run = mock.Mock(side_effect=wrapped_sysinfo_run)
+
+        run(["--sysinfo-plugins", "TestPlugin"], sysinfo=sysinfo)
+
+        sysinfo.run.assert_called_once_with()
 
         self.assertNotIn("Test note", self.stdout.getvalue())
         deferred.callback(None)
@@ -226,11 +231,10 @@ class RunTest(LandscapeTest):
         If landscape-sysinfo is running as a privileged user, then the logs
         should be stored in the system-wide log directory.
         """
-        uid_mock = self.mocker.replace("os.getuid")
-        uid_mock()
-        self.mocker.result(0)
-        self.mocker.replay()
-        self.assertEqual(get_landscape_log_directory(), "/var/log/landscape")
+        with mock.patch("os.getuid", return_value=0) as uid_mock:
+            self.assertEqual(
+                get_landscape_log_directory(), "/var/log/landscape")
+            uid_mock.assert_called_once_with()
 
     def test_wb_logging_setup(self):
         """
@@ -250,24 +254,23 @@ class RunTest(LandscapeTest):
         self.assertFalse(logger.propagate)
 
     def test_setup_logging_logs_to_var_log_if_run_as_root(self):
-        mock_os = self.mocker.replace("os")
-        mock_os.getuid()
-        self.mocker.result(0)
+        with mock.patch.object(os, "getuid", return_value=0) as mock_getuid, \
+                mock.patch.object(
+                    os.path, "isdir", return_value=False) as mock_isdir, \
+                mock.patch.object(os, "mkdir") as mock_mkdir, \
+                mock.patch("logging.open") as mock_open:
+            logger = getLogger("landscape-sysinfo")
+            self.assertEqual(logger.handlers, [])
 
-        # Ugh, sorry
-        mock_os.path.isdir("/var/log/landscape")
-        self.mocker.result(False)
-        mock_os.mkdir("/var/log/landscape")
+            setup_logging()
 
-        self.mocker.replace("__builtin__.open", passthrough=False)(
-            "/var/log/landscape/sysinfo.log", "a")
-
-        self.mocker.replay()
-
-        logger = getLogger("landscape-sysinfo")
-        self.assertEqual(logger.handlers, [])
-
-        setup_logging()
+        mock_getuid.assert_called_with()
+        mock_isdir.assert_called_with("/var/log/landscape")
+        mock_mkdir.assert_called_with("/var/log/landscape")
+        self.assertEqual(
+            mock_open.call_args_list[0][0],
+            ("/var/log/landscape/sysinfo.log", "a")
+        )
         handler = logger.handlers[0]
         self.assertTrue(isinstance(handler, RotatingFileHandler))
         self.assertEqual(handler.baseFilename,
@@ -280,20 +283,18 @@ class RunTest(LandscapeTest):
         self.assertTrue(os.path.exists(log_dir))
 
     def test_run_sets_up_logging(self):
-        setup_logging_mock = self.mocker.replace(
-            "landscape.sysinfo.deployment.setup_logging")
-        setup_logging_mock()
-        self.mocker.replay()
-
-        run(["--sysinfo-plugins", "TestPlugin"])
+        with mock.patch(
+                "landscape.sysinfo.deployment"
+                ".setup_logging") as setup_logging_mock:
+            run(["--sysinfo-plugins", "TestPlugin"])
+        setup_logging_mock.assert_called_once_with()
 
     def test_run_setup_logging_exits_gracefully(self):
-        setup_logging_mock = self.mocker.replace(
-            "landscape.sysinfo.deployment.setup_logging")
-        setup_logging_mock()
-        self.mocker.throw(IOError("Read-only filesystem."))
-        self.mocker.replay()
-        error = self.assertRaises(SystemExit, run,
-                                  ["--sysinfo-plugins", "TestPlugin"])
-        self.assertEqual(error.message,
-                         "Unable to setup logging. Read-only filesystem.")
+        io_error = IOError("Read-only filesystem.")
+        with mock.patch(
+                "landscape.sysinfo.deployment.setup_logging",
+                side_effect=io_error):
+            error = self.assertRaises(
+                SystemExit, run, ["--sysinfo-plugins", "TestPlugin"])
+        self.assertEqual(
+            error.code, "Unable to setup logging. Read-only filesystem.")
