@@ -1,9 +1,13 @@
+import unittest
+
+import mock
+
+from landscape.lib.testing import TwistedTestCase
 from landscape.sysinfo.sysinfo import SysInfoPluginRegistry
 from landscape.sysinfo.load import Load
-from landscape.tests.helpers import LandscapeTest
 
 
-class LoadTest(LandscapeTest):
+class LoadTest(TwistedTestCase, unittest.TestCase):
 
     def setUp(self):
         super(LoadTest, self).setUp()
@@ -14,13 +18,10 @@ class LoadTest(LandscapeTest):
     def test_run_returns_succeeded_deferred(self):
         self.assertIs(None, self.successResultOf(self.load.run()))
 
-    def test_run_adds_header(self):
-        mock = self.mocker.replace("os.getloadavg")
-        mock()
-        self.mocker.result((1.5, 0, 0))
-        self.mocker.replay()
-
+    @mock.patch("os.getloadavg", return_value=(1.5, 0, 0))
+    def test_run_adds_header(self, mock_getloadavg):
         self.load.run()
 
+        mock_getloadavg.assert_called_once_with()
         self.assertEqual(self.sysinfo.get_headers(),
                          [("System load", "1.5")])
