@@ -1,15 +1,17 @@
-from cStringIO import StringIO
 from logging import getLogger, StreamHandler
+import mock
 import os
+import unittest
 
 from twisted.internet.defer import Deferred, succeed, fail
 
+from landscape.lib.compat import StringIO
+from landscape.lib.plugin import PluginRegistry
+from landscape.lib.testing import HelperTestCase
 from landscape.sysinfo.sysinfo import SysInfoPluginRegistry, format_sysinfo
-from landscape.plugin import PluginRegistry
-from landscape.tests.helpers import LandscapeTest
 
 
-class SysInfoPluginRegistryTest(LandscapeTest):
+class SysInfoPluginRegistryTest(HelperTestCase):
 
     def setUp(self):
         super(SysInfoPluginRegistryTest, self).setUp()
@@ -210,18 +212,13 @@ class SysInfoPluginRegistryTest(LandscapeTest):
             self.sysinfo.get_notes(),
             [self.plugin_exception_message % path])
 
-    def test_exception_running_as_privileged_user(self):
+    @mock.patch("os.getuid", return_value=0)
+    def test_exception_running_as_privileged_user(self, uid_mock):
         """
         If a Plugin fails while running and the sysinfo binary is running with
         a uid of 0, Landscape sysinfo should write to the system logs
         directory.
         """
-        uid_mock = self.mocker.replace("os.getuid")
-        uid_mock()
-        self.mocker.count(1, max=None)
-        self.mocker.result(0)
-        self.mocker.replay()
-        self.log_helper.ignore_errors(ZeroDivisionError)
 
         class AsyncBadPlugin(object):
 
@@ -231,9 +228,12 @@ class SysInfoPluginRegistryTest(LandscapeTest):
             def run(self):
                 return fail(ZeroDivisionError("Hi"))
 
+        self.log_helper.ignore_errors(ZeroDivisionError)
+
         plugin = AsyncBadPlugin()
         self.sysinfo.add(plugin)
         self.sysinfo.run()
+        uid_mock.assert_called_with()
 
         path = "/var/log/landscape"
         self.assertEqual(
@@ -241,7 +241,7 @@ class SysInfoPluginRegistryTest(LandscapeTest):
             [self.plugin_exception_message % path])
 
 
-class FormatTest(LandscapeTest):
+class FormatTest(unittest.TestCase):
 
     def test_no_headers(self):
         output = format_sysinfo([])
@@ -264,8 +264,9 @@ class FormatTest(LandscapeTest):
     def test_stacked_headers_with_clearly_insufficient_space(self):
         output = format_sysinfo([("Header1", "Value1"),
                                  ("Header2", "Value2")], width=1)
-        self.assertEqual(output, "Header1: Value1\n"
-                                  "Header2: Value2")
+        self.assertEqual(output,
+                         "Header1: Value1\n"
+                         "Header2: Value2")
 
     def test_indent_headers_in_parallel_with_just_enough_space(self):
         output = format_sysinfo([("Header1", "Value1"),
@@ -275,8 +276,9 @@ class FormatTest(LandscapeTest):
     def test_indent_headers_stacked_which_barely_doesnt_fit(self):
         output = format_sysinfo([("Header1", "Value1"),
                                  ("Header2", "Value2")], indent=">>", width=35)
-        self.assertEqual(output, ">>Header1: Value1\n"
-                                  ">>Header2: Value2")
+        self.assertEqual(output,
+                         ">>Header1: Value1\n"
+                         ">>Header2: Value2")
 
     def test_parallel_and_stacked_headers(self):
         headers = [("Header%d" % i, "Value%d" % i) for i in range(1, 6)]
